Context

Struct Context 

pub struct Context { /* private fields */ }
A context of IR, dialects, and passes.

Contexts own various objects, such as types, locations, and dialect instances.

Implementations

Source

impl Context

pub fn new() -> Self

Creates a context.

pub fn new_with_threading(threading_enabled: bool) -> Self

Creates a context with multithreading set explicitly.

pub fn new_with_registry( registry: &DialectRegistry, threading_enabled: bool, ) -> Self

Creates a context with a pre-loaded dialect registry and explicit threading setting.

pub fn registered_dialect_count(&self) -> usize

Returns a number of registered dialects.

pub fn loaded_dialect_count(&self) -> usize

Returns a number of loaded dialects.

pub fn get_or_load_dialect<'c>(&'c self, name: &str) -> Dialect<'c>

Returns or loads a dialect.

pub fn append_dialect_registry(&self, registry: &DialectRegistry)

Appends a dialect registry.

pub fn load_all_available_dialects(&self)

Loads all available dialects.

pub fn enable_multi_threading(&self, enabled: bool)

Enables multi-threading.

pub fn allow_unregistered_dialects(&self) -> bool

Returns true if unregistered dialects are allowed.

pub fn set_allow_unregistered_dialects(&self, allowed: bool)

Sets if unregistered dialects are allowed.

pub fn is_registered_operation(&self, name: &str) -> bool

Returns true if a given operation is registered in a context.

pub const fn to_raw(&self) -> MlirContext

Converts a context into a raw object.

pub fn attach_diagnostic_handler<F: FnMut(Diagnostic<'_>) -> bool>( &self, handler: F, ) -> DiagnosticHandlerId

Attaches a diagnostic handler.

pub fn detach_diagnostic_handler(&self, id: DiagnosticHandlerId)

Detaches a diagnostic handler.

pub unsafe fn set_thread_pool(&self, pool: &ThreadPool)

Sets the thread pool used by the context.

Safety

The thread pool must outlive the context.

pub fn thread_count(&self) -> usize

Returns the number of threads used by the context.