ContextRef

Struct ContextRef 

pub struct ContextRef<'c> { /* private fields */ }
A reference to a context.

Implementations

Source

impl<'c> ContextRef<'c>

pub unsafe fn from_raw(raw: MlirContext) -> Self

Creates a context reference from a raw object.

Safety

A raw object must be valid.

pub unsafe fn to_ref(&self) -> &'c Context

Returns a context.

This function is different from deref because the correct lifetime is kept for the return type.

Safety

The returned reference is safe to use only in the lifetime scope of the context reference.