RewriterBase

Struct RewriterBase 

pub struct RewriterBase<'c, 'a> { /* private fields */ }
A non-owning reference to a rewriter base.

Implementations

Source

impl<'c, 'a> RewriterBase<'c, 'a>

pub unsafe fn from_raw(raw: MlirRewriterBase) -> Self

Creates a rewriter base from a raw object.

Safety

A raw object must be valid.

pub fn context(&self) -> ContextRef<'c>

Returns the context.

pub fn clear_insertion_point(&self)

Clears the insertion point.

pub fn set_insertion_point_before(&self, op: OperationRef<'_, '_>)

Sets the insertion point before the given operation.

pub fn set_insertion_point_after(&self, op: OperationRef<'_, '_>)

Sets the insertion point after the given operation.

pub fn set_insertion_point_to_start(&self, block: BlockRef<'_, '_>)

Sets the insertion point to the start of the given block.

pub fn set_insertion_point_to_end(&self, block: BlockRef<'_, '_>)

Sets the insertion point to the end of the given block.

pub fn insertion_block(&self) -> BlockRef<'c, '_>

Returns the block the insertion point belongs to.

pub fn block(&self) -> BlockRef<'c, '_>

Returns the current block.

pub fn insert(&self, op: Operation<'c>) -> OperationRef<'c, '_>

Inserts the operation at the current insertion point and returns a reference to it.

pub fn clone_op<'b>(&self, op: OperationRef<'c, 'b>) -> OperationRef<'c, 'b>

Creates a deep copy of the operation.

pub fn clone_op_without_regions<'b>( &self, op: OperationRef<'c, 'b>, ) -> OperationRef<'c, 'b>

Creates a deep copy of the operation without its regions.

pub fn clone_region_before( &self, region: RegionRef<'_, '_>, before: BlockRef<'_, '_>, )

Clones the blocks of the region before the given block.

pub fn inline_region_before( &self, region: RegionRef<'_, '_>, before: BlockRef<'_, '_>, )

Moves the blocks of the region before the given block.

pub fn replace_op_with_values( &self, op: OperationRef<'_, '_>, values: &[Value<'_, '_>], )

Replaces the results of the operation with the given values. Erases the op.

pub fn replace_op_with_operation( &self, op: OperationRef<'_, '_>, new_op: OperationRef<'_, '_>, )

Replaces the operation with another operation. Erases the original op.

pub fn erase_op(&self, op: OperationRef<'_, '_>)

Erases the operation. The operation must have no uses.

pub fn erase_block(&self, block: BlockRef<'_, '_>)

Erases the block along with all its operations.

pub fn move_op_before( &self, op: OperationRef<'_, '_>, existing_op: OperationRef<'_, '_>, )

Moves the operation immediately before the existing operation.

pub fn move_op_after( &self, op: OperationRef<'_, '_>, existing_op: OperationRef<'_, '_>, )

Moves the operation immediately after the existing operation.

pub fn move_block_before( &self, block: BlockRef<'_, '_>, existing_block: BlockRef<'_, '_>, )

Moves the block immediately before the existing block.

pub fn start_op_modification(&self, op: OperationRef<'_, '_>)

Signals the start of an in-place modification of the operation.

pub fn finalize_op_modification(&self, op: OperationRef<'_, '_>)

Signals the end of an in-place modification of the operation.

pub fn cancel_op_modification(&self, op: OperationRef<'_, '_>)

Cancels a pending in-place modification of the operation.

pub fn replace_all_uses_with(&self, from: Value<'_, '_>, to: Value<'_, '_>)

Replaces all uses of from with to.