pub fn create_op_rewrite_pattern<F>(
root_name: &str,
benefit: u32,
context: &Context,
callback: F,
generated_names: &[&str],
) -> RewritePatternExpand description
Creates an op rewrite pattern that matches operations with the given root name.
The callback receives the pattern, the matched operation, and a pattern
rewriter. It should perform the rewrite and return true on success.